/*
*  Copyright (c) 2011-2016 Samsung Electronics Co., Ltd All Rights Reserved 
*  Licensed under the Apache License, Version 2.0 (the "License");
*  you may not use this file except in compliance with the License.
*  You may obtain a copy of the License at
*  http://www.apache.org/licenses/LICENSE-2.0
*  Unless required by applicable law or agreed to in writing, software
*  distributed under the License is distributed on an "AS IS" BASIS,
*  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
*  See the License for the specific language governing permissions and
*  limitations under the License.
*/


#ifndef __TTSD_SERVER_CORE_H_
#define __TTSD_SERVER_CORE_H_

#include <glib.h>
#include <Ecore.h>

#include "ttse.h"

#ifdef __cplusplus
extern "C" {
#endif

/**
* Server APIs
*/
int ttsd_initialize(ttse_request_callback_s *callback);

int ttsd_finalize();

int ttsd_terminate();

Eina_Bool ttsd_cleanup_client(void *data);

Eina_Bool ttsd_get_daemon_exist();

int ttsd_send_result(ttse_result_event_e event, const void* data, unsigned int data_size, ttse_audio_type_e audio_type, int rate, void* user_data);
int ttsd_send_error(ttse_error_e error, const char* msg);

int ttsd_set_private_data_set_cb(ttse_private_data_set_cb callback);
int ttsd_set_private_data_requested_cb(ttse_private_data_requested_cb callback);

/*
* Server API for client
*/

int ttsd_server_is_already_initialized(int pid, int uid, bool* is_initialized);

int ttsd_server_initialize(int pid, int uid, bool* credential_needed);

int ttsd_server_finalize(int uid);

int ttsd_server_get_support_voices(int uid, GList** voice_list);

int ttsd_server_get_current_voice(int uid, char** language, int* voice_type);

int ttsd_server_add_queue(int uid, const char* text, const char* lang, int voice_type, int speed, int utt_id, const char* credential);

int ttsd_server_play(int uid, const char* credential);

int ttsd_server_stop(int uid);

int ttsd_server_pause(int uid, int* utt_id);

int ttsd_server_set_private_data(int uid, const char* key, const char* data);

int ttsd_server_get_private_data(int uid, const char* key, char** data);

int ttsd_server_play_pcm(int uid);

int ttsd_server_stop_pcm(int uid);

int ttsd_server_add_pcm(int uid, int event, void* data, int data_size, int audio_type, int rate);

#ifdef __cplusplus
}
#endif

#endif /* __TTSD_SERVER_CORE_H_ */
